package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.crypto.digests.SHA1Digest;

public class SubjectKeyIdentifier extends ASN1Encodable {
   private byte[] keyidentifier;

   public static SubjectKeyIdentifier getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1OctetString.getInstance(obj, explicit));
   }

   public static SubjectKeyIdentifier getInstance(Object obj) {
      if (obj instanceof SubjectKeyIdentifier) {
         return (SubjectKeyIdentifier)obj;
      } else if (obj instanceof SubjectPublicKeyInfo) {
         return new SubjectKeyIdentifier((SubjectPublicKeyInfo)obj);
      } else if (obj instanceof ASN1OctetString) {
         return new SubjectKeyIdentifier((ASN1OctetString)obj);
      } else if (obj instanceof X509Extension) {
         return getInstance(X509Extension.convertValueToObject((X509Extension)obj));
      } else {
         throw new IllegalArgumentException("Invalid SubjectKeyIdentifier: " + obj.getClass().getName());
      }
   }

   public SubjectKeyIdentifier(byte[] keyid) {
      this.keyidentifier = keyid;
   }

   public SubjectKeyIdentifier(ASN1OctetString keyid) {
      this.keyidentifier = keyid.getOctets();
   }

   public SubjectKeyIdentifier(SubjectPublicKeyInfo spki) {
      SubjectKeyIdentifier var10000 = this;
      super();
      SHA1Digest var10001 = new SHA1Digest();
      byte[] var2 = new byte[var10001.getDigestSize()];
      byte[] var10003 = spki.getPublicKeyData().getBytes();
      var10001.update(var10003, 0, var10003.length);
      var10001.doFinal(var2, 0);
      var10000.keyidentifier = var2;
   }

   public byte[] getKeyIdentifier() {
      return this.keyidentifier;
   }

   public DERObject toASN1Object() {
      return new DEROctetString(this.keyidentifier);
   }
}
